Module io

Module io 

Generic multi-channel signal I/O abstraction

Signal I/O — generic multi-channel real-time I/O abstraction

Traits

IoBackend
Backward-compatible alias for code that only needs a driver.
IoCapture
A backend that captures (reads) signal data from hardware.
IoControl
Control interface for backends that accept operational data separate from the signal stream (e.g. chip register writes).
IoDriver
A backend that can be the clock driver for the signal graph.
IoPlayback
A backend that plays (writes) signal data to hardware.

Type Aliases

IoResult
Result alias for signal I/O operations.