pub trait IoBackend: IoDriver { }Expand description
Backward-compatible alias for code that only needs a driver.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
pub trait IoBackend: IoDriver { }Backward-compatible alias for code that only needs a driver.
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".