macro_rules! context {
($expr:expr, $code:expr, $msg:expr) => { ... };
($expr:expr, $code:expr, $fmt:expr, $($arg:tt)*) => { ... };
}Expand description
Transform a Result by mapping the error with additional context.
macro_rules! context {
($expr:expr, $code:expr, $msg:expr) => { ... };
($expr:expr, $code:expr, $fmt:expr, $($arg:tt)*) => { ... };
}Transform a Result by mapping the error with additional context.