Module functions

Module functions 

Common mathematical functions for signal processing

Functions

db_to_linear
Convert decibels to a linear coefficient
deinterleave_stereo
Deinterleave stereo interleaved buffer into two mono buffers (SIMD).
f32_to_i16_chunk
Convert f32 chunk to i16 with SIMD clamping and scaling.
fast_tanh
Fast tanh approximation
hann_window
Hann window
i16_to_f32_chunk
Convert i16 chunk to f32 with SIMD scaling.
interleave_stereo
Interleave two mono buffers into a stereo interleaved buffer (SIMD).
lerp
Linear interpolation
linear_to_db
Convert a linear coefficient to decibels
samples_to_seconds
Convert samples to seconds
seconds_to_samples
Convert seconds to samples
soft_clip
Soft clipping