Module simd

Module simd 

Available on x86 or x86-64 only.
SIMD-accelerated vector implementations.

SIMD implementations for vector operations

This module contains platform-dependent SIMD implementations of vector operations.

CPU feature detection

The system automatically determines available SIMD instructions at runtime and selects the optimal implementation.

Supported architectures

  • x86/x86_64: SSE2, SSE4.1, AVX, AVX2, AVX512
  • ARM: NEON (AArch64)
  • WebAssembly: SIMD128

Usage

Users typically don’t interact with this module directly, but use the high-level abstractions from vector::traits.

Re-exports

pub use wide::*;simd

Modules

widesimd
Cross-platform SIMD implementations via the wide crate
x86
x86/x86_64 SIMD implementations

Structs

SimdDetector
SIMD capability detector for the CPU