Struct F64x2
Source pub struct F64x2();
Available on (x86 or x86-64) and crate feature simd only.
SIMD вектор из 2 элементов f64
The resulting type after applying the + operator.
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Returns the “default value” for a type.
Read more
The resulting type after applying the / operator.
The resulting type after applying the * operator.
The resulting type after applying the - operator.
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
The resulting type after applying the % operator.
The resulting type after applying the - operator.
Construct a vector with all lanes set to the same value.
Load a vector from a slice (panics if slice is too short).
Store the vector lanes into a slice.
Extract the value at the given lane index.
Return a new vector with the value at the given lane replaced.
Lane-wise addition.
Lane-wise subtraction.
Lane-wise multiplication.
Lane-wise division.
Lane-wise remainder.
Lane-wise negation.
Lane-wise absolute value.
Lane-wise minimum.
Lane-wise maximum.
Lane-wise clamp to the inclusive range [min, max].
Lane-wise square root.
Lane-wise exponential (e^x).
Lane-wise natural logarithm.
Lane-wise sine (input in radians).
Lane-wise cosine (input in radians).
Lane-wise tangent (input in radians).
Convert to &dyn std::any::Any
Convert to &mut dyn std::any::Any
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more
Uses borrowed data to replace owned data, usually by cloning.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.