pub trait Command:
Send
+ 'static
+ Debug { }Expand description
Base trait for all commands.
Any type implementing this trait can be sent through a command queue.
pub trait Command:
Send
+ 'static
+ Debug { }Base trait for all commands.
Any type implementing this trait can be sent through a command queue.