Module control_event

Module control_event 

Signal and command types for automation. Control events โ€” hardware input events decoded from sensors.

These types represent raw control input from physical interfaces (MIDI controllers, OSC surfaces, buttons, knobs, faders) and MIDI transport/clock events. They are decoded by sensors and dispatched to servos for mapping to graph parameters.

Enums

ControlEvent
Hardware control event from a physical interface (knob, button, fader, etc.).
EventPattern
A pattern for matching controller events.
MidiNoteKind
What aspect of a MIDI note event to extract for mapping.
MidiTransportKind
MIDI transport state.