Telemetry

Enum Telemetry 

pub enum Telemetry {
    ParameterValue {
        port: PortId,
        parameter: ParameterId,
        value: f32,
        timestamp: u64,
    },
    SignalData {
        node_id: NodeId,
        channel: usize,
        data: Vec<f32>,
        timestamp: u64,
        sample_rate: f32,
    },
    Peak {
        port: PortId,
        value: f32,
        timestamp: u64,
        hold_time_ms: Option<u32>,
    },
    Event {
        source: String,
        kind: String,
        data: Vec<f32>,
        timestamp: u64,
        description: Option<String>,
    },
    Violation {
        component: String,
        expected_ns: u64,
        actual_ns: u64,
        value: Option<f32>,
        timestamp: u64,
    },
}
Telemetry data emitted by signal graph nodes.

Variants



ParameterValue

A parameter value change.

Fields

port: PortId

Target port.

parameter: ParameterId

Target parameter.

value: f32

Current parameter value.

timestamp: u64

Unix timestamp (microseconds).



SignalData

Audio or sensor signal data.

Fields

node_id: NodeId

Source node ID.

channel: usize

Channel index.

data: Vec<f32>

Signal sample data.

timestamp: u64

Unix timestamp (microseconds).

sample_rate: f32

Sample rate of the signal.



Peak

Peak value reading.

Fields

port: PortId

Target port.

value: f32

Peak value.

timestamp: u64

Unix timestamp (microseconds).

hold_time_ms: Option<u32>

Optional hold time in milliseconds.



Event

Named event with float payload.

Fields

source: String

Source component name.

kind: String

Event kind string.

data: Vec<f32>

Event data payload.

timestamp: u64

Unix timestamp (microseconds).

description: Option<String>

Optional human-readable description.



Violation

Micro-control timing violation.

Fields

component: String

Component that exceeded its time budget.

expected_ns: u64

Expected execution time (nanoseconds).

actual_ns: u64

Actual execution time (nanoseconds).

value: Option<f32>

Optional associated value.

timestamp: u64

Unix timestamp (microseconds).

Implementations

Source

impl Telemetry

pub fn now() -> u64

Return the current Unix time in microseconds.

pub fn parameter(port: PortId, parameter: ParameterId, value: f32) -> Self

Create a parameter value telemetry event.

pub fn parameter_with_time( port: PortId, parameter: ParameterId, value: f32, timestamp: u64, ) -> Self

Create a parameter value telemetry event with an explicit timestamp (for testing).

pub fn signal(node_id: NodeId, channel: usize, data: Vec<f32>) -> Self

Create a signal data telemetry event.

pub fn signal_with_sample_rate( node_id: NodeId, channel: usize, data: Vec<f32>, sample_rate: f32, ) -> Self

Create a signal data telemetry event with an explicit sample rate.

pub fn peak(port: PortId, value: f32) -> Self

Create a peak value telemetry event.

pub fn peak_with_hold(port: PortId, value: f32, hold_time_ms: u32) -> Self

Create a peak value telemetry event with a hold time.

pub fn event( source: impl Into<String>, kind: impl Into<String>, data: Vec<f32>, ) -> Self

Create an event telemetry event.

pub fn event_with_description( source: impl Into<String>, kind: impl Into<String>, data: Vec<f32>, description: impl Into<String>, ) -> Self

Create an event telemetry event with a description.

pub fn violation( component: impl Into<String>, expected_ns: u64, actual_ns: u64, value: Option<f32>, ) -> Self

Create a micro-control violation telemetry event.

pub fn kind(&self) -> TelemetryKind

Return the telemetry type category.

pub fn timestamp(&self) -> u64

Return the timestamp (microseconds since Unix epoch).