Processor

Trait Processor 

pub trait Processor<T: Transcendental, const BUF_SIZE: usize>: SignalNode<T, BUF_SIZE> {
    // Required method
    fn process(
        &mut self,
        clock: &ClockTick,
        signal_inputs: &[&[T; BUF_SIZE]],
        control_inputs: &[T],
        clock_inputs: &[ClockTick],
        feedback_inputs: &[&[T; BUF_SIZE]],
    ) -> ProcessResult<()>;

    // Provided method
    fn latency(&self) -> usize { ... }
}
Passive processor of signals

Processors transform input signals into output signals. They have audio inputs and outputs, and may have control and clock ports.

Required Methods

fn process( &mut self, clock: &ClockTick, signal_inputs: &[&[T; BUF_SIZE]], control_inputs: &[T], clock_inputs: &[ClockTick], feedback_inputs: &[&[T; BUF_SIZE]], ) -> ProcessResult<()>

Process a block of audio

Arguments
  • clock - Current clock tick
  • signal_inputs - Audio input buffers (one per audio input)
  • control_inputs - Control signal values (one per control input)
  • clock_inputs - Clock signal values (one per clock input)
  • feedback_inputs - Feedback values from previous blocks (one per feedback port)

The processor writes output samples into its own output port buffers, accessible via self.output_port_mut(index).

Provided Methods

fn latency(&self) -> usize

Latency in samples (for delay compensation)