Module processable

Module processable 

Processing traits (Processable, Processor, Source, Sink). Processable trait and NodeVariant.

Enums

NodeVariant
A type-erased node that wraps any of the four node roles.

Traits

Processable
A node or component that can process a block of signal data.