ProcessContext

Struct ProcessContext 

pub struct ProcessContext<'a, T: Transcendental, const BUF_SIZE: usize> {
    pub clock: &'a ClockTick,
    pub signal_inputs: &'a [&'a [T; BUF_SIZE]],
    pub control_inputs: &'a [T],
    pub clock_inputs: &'a [ClockTick],
    pub feedback_inputs: &'a [&'a [T; BUF_SIZE]],
}
Convenience structure that gathers all input buffers for a node.

Nodes write their output directly into their own output port buffers (accessible via SignalNode::output_port_mut), so only input data is passed through this context.

Fields

clock: &'a ClockTick

Current clock tick

signal_inputs: &'a [&'a [T; BUF_SIZE]]

Audio input buffers (slice of references to [T; BUF_SIZE])

control_inputs: &'a [T]

Control input values (slice of T)

clock_inputs: &'a [ClockTick]

Clock input ticks

feedback_inputs: &'a [&'a [T; BUF_SIZE]]

Feedback input buffers (slice of references to [T; BUF_SIZE])