macro_rules! vec_expr {
($val:expr) => { ... };
}Expand description
Creates a lazy vector expression (stub).
In the current implementation, the expr module is temporarily disabled due to compilation
errors, so this macro returns the passed value unchanged.