Macros for node creation and boilerplate reduction
Macros for creating nodes and working with the core
This module provides macros to simplify creating various types of nodes in Rill.
Modules
- prelude
- Prelude for convenient import of all macros
Macros
- node
- General macro for creating any type of node
- processor_
node - Creates a passive signal processor
- sink_
node - Creates an active signal receiver
- source_
node - Creates an active signal source
- with_
parameters - Adding parameters to an existing node