Common mathematical functions for signal processing
Functions
- db_
to_ linear - Convert decibels to a linear coefficient
- deinterleave_
stereo - Deinterleave stereo interleaved buffer into two mono buffers (SIMD).
- f32_
to_ i16_ chunk - Convert f32 chunk to i16 with SIMD clamping and scaling.
- fast_
tanh - Fast tanh approximation
- hann_
window - Hann window
- i16_
to_ f32_ chunk - Convert i16 chunk to f32 with SIMD scaling.
- interleave_
stereo - Interleave two mono buffers into a stereo interleaved buffer (SIMD).
- lerp
- Linear interpolation
- linear_
to_ db - Convert a linear coefficient to decibels
- samples_
to_ seconds - Convert samples to seconds
- seconds_
to_ samples - Convert seconds to samples
- soft_
clip - Soft clipping