Bounded command queue using a crossbeam channel.
CommandQueue — non-blocking command queue
CommandQueue provides safe command transfer from the control thread
to the audio signal thread via a bounded crossbeam channel.
Structs
- Command
Queue - Non-blocking bounded command queue.
- Command
Receiver - Receiver half of a command queue (consumed by the signal thread).
- Command
Sender - Sender half of a command queue.
Traits
- Command
- Base trait for all commands.