Signal and command types for automation. Control events โ hardware input events decoded from sensors.
These types represent raw control input from physical interfaces (MIDI controllers, OSC surfaces, buttons, knobs, faders) and MIDI transport/clock events. They are decoded by sensors and dispatched to servos for mapping to graph parameters.
Enums
- Control
Event - Hardware control event from a physical interface (knob, button, fader, etc.).
- Event
Pattern - A pattern for matching controller events.
- Midi
Note Kind - What aspect of a MIDI note event to extract for mapping.
- Midi
Transport Kind - MIDI transport state.