pub enum Telemetry {
ParameterValue {
port: PortId,
parameter: ParameterId,
value: f32,
timestamp: u64,
},
SignalData {
node_id: NodeId,
channel: usize,
data: Vec<f32>,
timestamp: u64,
sample_rate: f32,
},
Peak {
port: PortId,
value: f32,
timestamp: u64,
hold_time_ms: Option<u32>,
},
Event {
source: String,
kind: String,
data: Vec<f32>,
timestamp: u64,
description: Option<String>,
},
Violation {
component: String,
expected_ns: u64,
actual_ns: u64,
value: Option<f32>,
timestamp: u64,
},
}Expand description
Telemetry data emitted by signal graph nodes.
Variants
ParameterValue
A parameter value change.
Fields

parameter: ParameterIdTarget parameter.
SignalData
Audio or sensor signal data.
Fields
Peak
Peak value reading.
Fields
Event
Named event with float payload.
Fields
Violation
Micro-control timing violation.
Implementations
Sourceimpl Telemetry
impl Telemetry
Sourcepub fn parameter(port: PortId, parameter: ParameterId, value: f32) -> Self
pub fn parameter(port: PortId, parameter: ParameterId, value: f32) -> Self
Create a parameter value telemetry event.
Sourcepub fn parameter_with_time(
port: PortId,
parameter: ParameterId,
value: f32,
timestamp: u64,
) -> Self
pub fn parameter_with_time( port: PortId, parameter: ParameterId, value: f32, timestamp: u64, ) -> Self
Create a parameter value telemetry event with an explicit timestamp (for testing).
Sourcepub fn signal(node_id: NodeId, channel: usize, data: Vec<f32>) -> Self
pub fn signal(node_id: NodeId, channel: usize, data: Vec<f32>) -> Self
Create a signal data telemetry event.
Sourcepub fn signal_with_sample_rate(
node_id: NodeId,
channel: usize,
data: Vec<f32>,
sample_rate: f32,
) -> Self
pub fn signal_with_sample_rate( node_id: NodeId, channel: usize, data: Vec<f32>, sample_rate: f32, ) -> Self
Create a signal data telemetry event with an explicit sample rate.
Sourcepub fn peak_with_hold(port: PortId, value: f32, hold_time_ms: u32) -> Self
pub fn peak_with_hold(port: PortId, value: f32, hold_time_ms: u32) -> Self
Create a peak value telemetry event with a hold time.
Sourcepub fn event(
source: impl Into<String>,
kind: impl Into<String>,
data: Vec<f32>,
) -> Self
pub fn event( source: impl Into<String>, kind: impl Into<String>, data: Vec<f32>, ) -> Self
Create an event telemetry event.
Sourcepub fn event_with_description(
source: impl Into<String>,
kind: impl Into<String>,
data: Vec<f32>,
description: impl Into<String>,
) -> Self
pub fn event_with_description( source: impl Into<String>, kind: impl Into<String>, data: Vec<f32>, description: impl Into<String>, ) -> Self
Create an event telemetry event with a description.
Sourcepub fn violation(
component: impl Into<String>,
expected_ns: u64,
actual_ns: u64,
value: Option<f32>,
) -> Self
pub fn violation( component: impl Into<String>, expected_ns: u64, actual_ns: u64, value: Option<f32>, ) -> Self
Create a micro-control violation telemetry event.
Sourcepub fn kind(&self) -> TelemetryKind
pub fn kind(&self) -> TelemetryKind
Return the telemetry type category.