Parameter types and IDs (ParameterId, ParamValue, ParamType, etc.).
Parameter handling for signal nodes
Defines the fundamental building blocks of the signal graph:
Node: Base trait for all nodesSource: Active generator (has no inputs)Processor: Passive processor (has inputs and outputs)Sink: Active consumer (has no outputs)
Structs
- Param
Metadata - Metadata about a parameter
- Param
Range - Range constraints for a parameter
- Parameter
Id - Type-safe parameter identifier with validation
- Params
- A flexible set of parameters passed to a node constructor.
- Signal
Slab - Pre-loaded, deinterleaved signal data ready for playback.
Enums
- Param
Type - Type of parameter value
- Param
Value - Parameter value (can be of different types)