pub trait Processable<T: Transcendental, const BUF_SIZE: usize> {
// Required method
fn process_block(
&mut self,
ctx: &mut ProcessContext<'_>,
) -> ProcessResult<()>;
}Expand description
A node or component that can process a block of signal data.
This is the main execution trait for the signal graph. Each node type
(Source, Processor, Router, Sink) implements this via blanket impls
that delegate to their respective generate/process/route/consume.
Required Methods
Sourcefn process_block(&mut self, ctx: &mut ProcessContext<'_>) -> ProcessResult<()>
fn process_block(&mut self, ctx: &mut ProcessContext<'_>) -> ProcessResult<()>
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".